@@ -61,6 +61,9 @@
 #' @param agemax maximum age of species; default NULL, then estimated from Linf
 #' @param flagging.out logical; should positive peaks be flagged out? Original setting of
 #' ELEFAN in TRUE. Default:TRUE
+#' @param seed an integer value containing the random number generator state. This
+#' argument can be used to replicate the results of a GA search. Note that
+#' if parallel computing is required, the doRNG package must be installed.
 #' @param plot logical; Plot restructured counts with fitted lines using
 #' \code{\link{plot.lfq}} and \code{\link{lfqFitCurves}} (default : FALSE).
 #' @param plot.score logical; Plot genetic algorithm fitness progression
@@ -109,6 +112,9 @@
 #' plot(synLFQ4, Fname="catch")
 #'
 #' # Genetic algorithm
+#' # (if using a multicore processor,
+#' #   consider adding the argument 'parallel=TRUE'
+#' #   to reduce computation time)
 #' output <- ELEFAN_GA(synLFQ4, seasonalised = TRUE,
 #'    low_par = list(Linf = 70, K = 0.25, t_anchor = 0, C = 0, ts= 0),
 #'    up_par = list(Linf = 90, K = 0.7, t_anchor = 1, C = 1, ts = 1),
@@ -130,6 +136,7 @@
 #' @import parallel
 #' @import doParallel
 #' @importFrom GA ga
+#' @importFrom utils flush.console
 #'
 #' @references
 #' Brey, T., Soriano, M., and Pauly, D. 1988. Electronic length frequency analysis: a
@@ -160,6 +167,7 @@ ELEFAN_GA <- function(
   addl.sqrt = FALSE,
   agemax = NULL,
   flagging.out = TRUE,
+  seed = 1,
   plot = FALSE,
   plot.score = TRUE,
   ...
@@ -238,6 +246,11 @@ ELEFAN_GA <- function(
     min = c(low_Linf, low_K, low_tanc, low_C, low_ts)
     max = c(up_Linf, up_K, up_tanc, up_C, up_ts)
 
+    writeLines(paste(
+      "Genetic algorithm is running. This might take some time.\n
+      A beep tone will alert completion."
+    ,sep=" "))
+    flush.console()
     fit <- GA::ga(
       type = "real-valued",
       fitness = sofun, lfq=lfq,
@@ -255,6 +268,9 @@ ELEFAN_GA <- function(
     min = c(low_Linf, low_K, low_tanc)
     max = c(up_Linf, up_K, up_tanc)
 
+    writeLines(paste(
+      "Genetic algorithm is running. \nThis will take some time. \nA beep tone will alert completion.",sep=" "))
+    flush.console()
     fit <- GA::ga(
       type = "real-valued",
       fitness = fun,
@@ -265,6 +281,7 @@ ELEFAN_GA <- function(
       flagging.out = flagging.out,
       popSize = popSize, maxiter = maxiter, run = run, parallel = parallel,
       pmutation = pmutation, pcrossover = pcrossover, elitism = elitism,
+      seed = seed,
       ...
     )
     pars <- as.list(fit@solution[1,])
